@@ -4,7 +4,7 @@ from platform import system
 import xdgconfig.mixins as mixins
 
 
-__version__ = '1.0.1'
+__version__ = '1.2.1'
 
 
 if system() == 'Windows':
@@ -35,6 +35,16 @@ class LocalIniConfig(mixins.IniMixin, LocalConfig):
     ...
 
 
+class PyConfig(mixins.PythonMixin, Config):
+    def save(self) -> None:
+        return
+
+
+class LocalPyConfig(mixins.PythonMixin, LocalConfig):
+    def save(self) -> None:
+        return
+
+
 if hasattr(mixins, 'XmlMixin'):
     class XmlConfig(mixins.XmlMixin, Config):
         ...
